==> style-o-matic-1.1.5.tgz: package/es/components/Icon/Icon.js <==
var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React from "react";
import { CoreComponent, getValidProps, setCorePropDefaults, ROLE } from "../../lib";
import "./Icon.css";

var Icon = (_temp = _class = function (_CoreComponent) {
  _inherits(Icon, _CoreComponent);

  function Icon() {
    _classCallCheck(this, Icon);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  Icon.prototype.render = function render() {
    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        children = _getValidProps.children,
        props = _getValidProps.props;

    return React.createElement(
      Component,
      props,
      children
    );
  };

  return Icon;
}(CoreComponent), _class.defaultProps = setCorePropDefaults({
  renderAs: "i",
  uirole: ROLE.ICON
}), _temp);


export default Icon;

==> style-o-matic-1.2.0.tgz: package/es/components/Icon/Icon.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * @memberof components
 * @namespace Icon
 * @author Steven Jackson
* @scss ../../scss/components/Icon
 * @example <Icon>
             Example Content
           </Icon>
 */
import React from "react";
import cx from "classnames";
import { CoreComponent, getValidProps, setCorePropDefaults, ROLE } from "../../lib";
import "./Icon.css";

var Icon = (_temp = _class = function (_CoreComponent) {
  _inherits(Icon, _CoreComponent);

  function Icon() {
    _classCallCheck(this, Icon);

    return _possibleConstructorReturn(this, _CoreComponent.apply(this, arguments));
  }

  Icon.prototype.render = function render() {
    var _classes;

    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        className = _getValidProps.className,
        children = _getValidProps.children,
        props = _getValidProps.props;

    var classes = (_classes = {}, _classes["ui-icon-" + children] = children, _classes);
    var iconClass = cx(className, classes);
    delete props.children;
    return React.createElement(Component, _extends({}, props, { className: iconClass }));
  };

  return Icon;
}(CoreComponent), _class.defaultProps = setCorePropDefaults({
  renderAs: "i",
  uirole: ROLE.ICON
}), _temp);


export default Icon;
